
**jalcon**: A falcon-based web framework
=======

**Getting started:**

> pip install jalcon

> jalcon-admin.py createproject project_name

> **then create an app**

> cd project_name

> pip install -r requirements.txt

> cd src

> python server.py startapp app_name

**TODO**: Make it have a pluggable app
